pub struct DynamicShortcut {
pub modifiers: Modifiers,
pub key: Key,
}Expand description
A keyboard shortcut that can be modified at runtime.
Unlike KeyboardShortcut which is typically a const, DynamicShortcut
is designed for user-configurable keybindings.
Serialization
When the serde feature is enabled, this type can be serialized/deserialized
for saving user preferences.
Fields
modifiers: ModifiersThe modifier keys (Ctrl, Shift, Alt, etc.)
key: KeyThe main key
Implementations
Sourceimpl DynamicShortcut
impl DynamicShortcut
Sourcepub const fn to_keyboard_shortcut(&self) -> KeyboardShortcut
pub const fn to_keyboard_shortcut(&self) -> KeyboardShortcut
Convert to egui’s KeyboardShortcut.