pub struct ShortcutGroup { /* private fields */ }Expand description
A group of shortcuts where any one can trigger the action.
Useful for supporting multiple shortcuts for the same action, like both “Cmd+Z” and “Ctrl+Z” for undo on different platforms.
Implementations
Sourceimpl ShortcutGroup
impl ShortcutGroup
Sourcepub fn with(self, shortcut: impl Into<DynamicShortcut>) -> Self
pub fn with(self, shortcut: impl Into<DynamicShortcut>) -> Self
Add a shortcut to the group.
Sourcepub fn add(&mut self, shortcut: impl Into<DynamicShortcut>)
pub fn add(&mut self, shortcut: impl Into<DynamicShortcut>)
Add a shortcut to the group.