DropZoneResponse

Struct DropZoneResponse 

pub struct DropZoneResponse<P, R> {
    pub inner: R,
    pub response: Response,
    pub payload: Option<Arc<P>>,
    pub is_being_dragged_over: bool,
}
Response from a drop zone

Fields

inner: R

The return value from the content closure

response: Response

The egui response

payload: Option<Arc<P>>

The payload if one was dropped

is_being_dragged_over: bool

Whether a compatible payload is being dragged over this zone

Implementations

Source

impl<P, R> DropZoneResponse<P, R>

pub fn on_drop<Msg, F>(self, ctx: &mut ViewCtx<'_, Msg>, f: F) -> Self
where F: FnOnce(Arc<P>) -> Msg,

Emit a message when a payload is dropped

pub fn on_hover<Msg>(self, ctx: &mut ViewCtx<'_, Msg>, msg: Msg) -> Self

Emit a message when hovering with a compatible payload

pub fn map<U>(self, f: impl FnOnce(R) -> U) -> DropZoneResponse<P, U>

Map the inner value