DynamicShortcut

Struct DynamicShortcut 

pub struct DynamicShortcut {
    pub modifiers: Modifiers,
    pub key: Key,
}
A keyboard shortcut that can be modified at runtime.

Unlike KeyboardShortcut which is typically a const, DynamicShortcut is designed for user-configurable keybindings.

Serialization

When the serde feature is enabled, this type can be serialized/deserialized for saving user preferences.

Fields

modifiers: Modifiers

The modifier keys (Ctrl, Shift, Alt, etc.)

key: Key

The main key

Implementations

Source

impl DynamicShortcut

pub const fn new(modifiers: Modifiers, key: Key) -> Self

Create a new dynamic shortcut.

pub const fn key_only(key: Key) -> Self

Create a shortcut with no modifiers.

pub const fn to_keyboard_shortcut(&self) -> KeyboardShortcut

Convert to egui’s KeyboardShortcut.